@@ -26,21 +26,18 @@ main(int argc, char **argv)
 
 	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
 	{
-		com_err(argv[0], err, "in ncp_initialize");
+		com_err(argv[0], err, "when initializing");
 		return 1;
 	}
-
 	if (argc > 2)
 	{
 		fprintf(stderr, "usage: %s [options] [pattern]\n", argv[0]);
 		return 1;
 	}
-
 	if (argc == 2)
 	{
 		pattern = argv[1];
 	}
-
 	for (p = pattern; *p != '\0'; p++)
 	{
 		*p = toupper(*p);
@@ -55,7 +52,6 @@ main(int argc, char **argv)
 		       "Print queue name",
 		       "Queue ID");
 	}
-
 	q.object_id = 0xffffffff;
 
 	while (ncp_scan_bindery_object(conn, q.object_id,
@@ -63,14 +59,13 @@ main(int argc, char **argv)
 	{
 		found = 1;
 		printf("%-52s", q.object_name);
-		printf("%08X\n", (unsigned int)q.object_id);
+		printf("%08X\n", (unsigned int) q.object_id);
 	}
 
 	if ((found == 0) && (isatty(1)))
 	{
 		printf("No queues found\n");
 	}
-
 	ncp_close(conn);
 	return 0;
 }
